@@ -33,9 +33,6 @@
 #include "asc.xpm"
 #include "dsc.xpm"
 
-#define CF ((GTopProcField *)c->data)
-#define CG (*((gint *)g->data))
-
 #define PROCVIEW_DATA_KEY	"procview_data"
 
 /* procview idle run or frozen */
@@ -215,7 +212,9 @@ procview_new (GTopProcViewData *d, GtkWidget *widget, gint ftype)
 	GTopProcView *procview = GTOP_PROCVIEW (widget);
 	GtkStyle *style;
 	int i;
-		
+
+	g_assert (d != NULL);
+
 	d->bin = GTK_WIDGET (procview);
 	d->ftype = (GTopProcViewType) ftype;
 
@@ -245,7 +244,11 @@ procview_new (GTopProcViewData *d, GtkWidget *widget, gint ftype)
 
 	if (config_remember_sorting) {
 		GList *c = g_list_nth (d->field_list, config_sort_field);
-		if (c) CF->order = config_sort_order ? SORT_ASC : SORT_DSC;
+		if (c) {
+		    GTopProcField *field = c->data;
+
+		    field->order = config_sort_order ? SORT_ASC : SORT_DSC;
+		}
 	}
 	
 	d->vbox = gtk_vbox_new (FALSE, 0);
@@ -320,6 +323,8 @@ procview_destroy (GtkWidget *widget)
 void
 procview_type_set (GTopProcViewData *d, gint ftype)
 {
+	g_assert (d != NULL);
+
 	d->ftype = ftype;
 }
 
@@ -327,11 +332,18 @@ static void
 procview_click_column (GtkCList *cl, gint n, GTopProcViewData *d)
 {
 	GtkWidget *arrow;
-	GList *c = g_list_nth (d->field_list, n);
-	gint nsf = CF - d->p_fields;
+	GTopProcField *field;
+	GList *c;
+	gint nsf;
+
+	c = g_list_nth (d->field_list, n);
+	if (!c) return;
+
+	field = c->data;
+	nsf = field - d->p_fields;
 
 	/* has compare function ??*/
-	if (!CF->compare)
+	if (!field->compare)
 		return;
 
 	if (d->sort_field >= 0) {
@@ -349,12 +361,11 @@ procview_click_column (GtkCList *cl, gint n, GTopProcViewData *d)
 	}
 
 	if (nsf == d->sort_field)
-
-		CF->order = (CF->order == SORT_ASC) ?
+		field->order = (field->order == SORT_ASC) ?
 			SORT_DSC : SORT_ASC;
 	
 	config_sort_field = n;
-	config_sort_order = (CF->order == SORT_ASC);
+	config_sort_order = (field->order == SORT_ASC);
 
 	if (config_remember_sorting) {
 		gnome_config_set_int ("gtop/procview/sort_field",
@@ -365,8 +376,8 @@ procview_click_column (GtkCList *cl, gint n, GTopProcViewData *d)
 	}
 
 	d->sort_field = nsf;
-	arrow = (CF->order == SORT_ASC) ? d->sort_asc : d->sort_dsc;
-	gtk_box_pack_start (GTK_BOX (CF->hb), arrow, FALSE, FALSE, 2);
+	arrow = (field->order == SORT_ASC) ? d->sort_asc : d->sort_dsc;
+	gtk_box_pack_start (GTK_BOX (field->hb), arrow, FALSE, FALSE, 2);
 	gtk_widget_show (arrow);
 	procview_update (d);
 }
@@ -712,9 +723,10 @@ procview_clist_prepare (GTopProcViewData *d)
 	while (c) {
 		GtkWidget *hb = GTK_BIN (cl->column[i].button)->child;
 		GtkBoxChild *bc = (GtkBoxChild *) GTK_BOX (hb)->children->data;
+		GTopProcField *field = c->data;
 		GtkStyle *style;
 
-		gtk_label_set (GTK_LABEL (bc->widget), _(CF->label));
+		gtk_label_set (GTK_LABEL (bc->widget), _(field->label));
 
 		gtk_widget_ensure_style (bc->widget);
 		style = gtk_style_copy (gtk_widget_get_style (bc->widget));
@@ -726,7 +738,7 @@ procview_clist_prepare (GTopProcViewData *d)
 		gtk_widget_set_style (bc->widget, style);
 		gtk_style_unref (style);
 
-		CF->hb = hb;
+		field->hb = hb;
 		c = c->next;
 		i++;
 	}
@@ -749,9 +761,12 @@ procview_clist_prepare (GTopProcViewData *d)
 	c = d->field_list;
 	i = 0;
 	while (c) {
+		GTopProcField *field = c->data;
+		gint *widthp = g->data;
+
 		gtk_clist_set_column_justification (GTK_CLIST (d->clist), i,
-						    CF->justification);
-		gtk_clist_set_column_width (GTK_CLIST (d->clist), i++, CG);
+						    field->justification);
+		gtk_clist_set_column_width (GTK_CLIST (d->clist), i++, *widthp);
 		c = c->next;
 		g = g->next;
 	}
@@ -775,9 +790,11 @@ procview_clist_update (GTopProcViewData *d)
 	while (c) {
 		GtkWidget *hb = GTK_BIN (cl->column[i].button)->child;
 		GtkBoxChild *bc = (GtkBoxChild *) GTK_BOX (hb)->children->data;
+		GTopProcField *field = c->data;
+		gint *widthp = g->data;
 		GtkStyle *style;
 
-		gtk_label_set (GTK_LABEL (bc->widget), _(CF->label));
+		gtk_label_set (GTK_LABEL (bc->widget), _(field->label));
 
 		gtk_widget_ensure_style (bc->widget);
 		style = gtk_style_copy (gtk_widget_get_style (bc->widget));
@@ -791,10 +808,10 @@ procview_clist_update (GTopProcViewData *d)
 		
 		gtk_clist_set_column_visibility (cl, i, TRUE);
 
-		gtk_clist_set_column_justification (cl, i, CF->justification);
-		gtk_clist_set_column_width (cl, i++, CG);
+		gtk_clist_set_column_justification (cl, i, field->justification);
+		gtk_clist_set_column_width (cl, i++, *widthp);
 
-		CF->hb = hb;
+		field->hb = hb;
 		c = c->next;
 		g = g->next;
 	}
@@ -953,7 +970,9 @@ procview_update_clist (GTopProcViewData *d, ProcProcData **pd)
 		j = 0;
 
 		while (c) {
-			text [j] = sprint_fmt (data, CF->fmt);
+			GTopProcField *field = c->data;
+
+			text [j] = sprint_fmt (data, field->fmt);
 			j++;
 			c = c->next;
 		}
